**********
Change-log
**********

v1.3.0
======

*   Adding readthedocs support

*   Adding link

*   Starting simple Sphinx docs

*   Automatic upload doxygen output to GH pages

*   Adding doxygen documentation

*   Removing Travis and Appveyor CI: Replaced by GH actions (#30)

*   Adding unit tests & GitHub CI (#28)

*   Map colormap on data (#26)

*   Extending tests (#21)

    -   Extending tests
    -   Using mamba for CI

*   [docs] Updated readme (#19)

*   [docs] Cropping image
